/** Copyright (C) 2017 by Bundesanstalt für Gewässerkunde
 * Software engineering by
 *  Björnsen Beratende Ingenieure GmbH
 *  Dr. Schumacher Ingenieurbüro für Wasser und Umwelt
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */
package org.dive4elements.river.artifacts.common;

import java.io.Serializable; 
import java.util.HashMap;
import java.util.Map;

import org.dive4elements.artifacts.CallContext;
import org.dive4elements.river.artifacts.common.IResultType;

/**
 * Generic container for results that come in rows.
 *
 * @author Gernot Belger
 */
public class ResultRow implements Serializable {
    protected static final long serialVersionUID = 1L; //TODO: Make private (wenn SInfoResultRow gelöscht ist

    private final Map<IResultType, Object> values = new HashMap<IResultType, Object>();

    public static ResultRow create() {
        return new ResultRow();
    }

    protected ResultRow() {
    }

    public ResultRow putValue(final IResultType type, final Object value) {

        this.values.put(type, value);

        /* chain me */
        return this;
    }

    public String exportValue(final CallContext context, final IResultType type) {
        final Object value = this.values.get(type);
        return type.exportValue(context, value);
    }

    public double getDoubleValue(final IResultType type) {
        final Object value = this.values.get(type);
        return type.asDouble(value);
    }

    public Object getValue(final IResultType type) {
        return this.values.get(type);
    }
}